﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Browser;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Xml;
using System.Xml.Linq;

namespace PubFinder1 {
	public partial class Page : UserControl {

		private String hostUriRoot = String.Empty;

		public List<Pub> Pubs { get; set; }

		public Page() {
			InitializeComponent();
			hostUriRoot = getUriRoot(HtmlPage.Document.DocumentUri);
			loadData();

			// Give the map's javascript file time to load otherwise the calls to AddPin may fail
			System.Threading.Thread.Sleep(1000);

			showMapLocations();
			setMapZoom(16);
			bindToDisplayList();
		}


		private void showMapLocations() {
			foreach (var pub in Pubs) {
				HtmlPage.Window.Invoke("AddPin", new String[] { pub.PubLat, pub.PubLong });
			}
		}

		private void setMapZoom(Int32 zoomLevel) {
			HtmlPage.Window.Invoke("SetZoom", new String[] { zoomLevel.ToString() });
		}

		private void loadData() {
			XDocument pubsXML = XDocument.Load("PubData.xml");

			var pubs = from pub in pubsXML.Descendants("pub")
					   select new Pub {
						   PubName = pub.Element("name").Value.Trim(),
						   PubAddress1 = pub.Element("address").Element("addressLine1").Value.Trim(),
						   PubTown = pub.Element("address").Element("town").Value.Trim(),
						   PubPostCode = pub.Element("address").Element("postCode").Value.Trim(),
						   PubPhone = pub.Element("contact").Element("phone").Value.Trim(),
						   PubImage = pub.Element("image").Element("uri").Value.Trim(),
						   PubLat = pub.Element("latLong").Element("latitude").Value.Trim(),
						   PubLong = pub.Element("latLong").Element("longitude").Value.Trim()
					   };

			this.Pubs = pubs.ToList();
		}

		private void bindToDisplayList() {
			PubList.ItemsSource = Pubs;
		}

		public void PubBorder_MouseLeftButtonDown(object sender, MouseButtonEventArgs e) {
			String pubLat = ((PubControl)sender).Latitude;
			String pubLong = ((PubControl)sender).Longitude;

			HtmlPage.Window.Invoke("MoveMapTo", new String[] { pubLat, pubLong });
		}

		private string getUriRoot(Uri uri) {
			return uri.GetComponents((UriComponents.Scheme | UriComponents.HostAndPort | UriComponents.KeepDelimiter), UriFormat.Unescaped);
		}

	}
}
